<?php 
$lang['title'] = 'Авторизація';

$lang['ln_login'] = 'Логін';
$lang['ln_pass'] = 'Пароль';

$lang['ln_remember'] = 'Запам’ятати мене';
$lang['ln_enter'] = 'Увійти';

$lang['msg_incorrect_pass'] = 'Невірний логін або пароль';

