<?php
// CRUD add new buttons
$lang['add_new_page'] = 'новую страницу';
$lang['add_new_template'] = 'новый темплейт';
$lang['add_new_menu'] = 'новый пункт меню';

$lang['crud_image'] = 'Изображение';
$lang['crud_page'] = 'Страница';
$lang['crud_content'] = 'Содержимое';
$lang['crud_template'] = 'Темплейт';
$lang['crud_menu'] = 'Пункт меню';
$lang['crud_parent_id'] = 'Родительский элемент';
$lang['crud_view_order'] = 'Порядок отображения';
$lang['active'] = 'Активно';

