<form id="install_form" action="" method="post">
    {items}
    <div class="control-group">
        <label class="control-label" for="input{name}">{ln_name}</label>
        <div class="controls">
            <input type="text" id="{name}" value="{value}" name="{name}" placeholder="{placeholder}">
        </div>
    </div>
    {/items}
    <div class="form-actions">
        <button type="submit" class="btn btn-success">{ln_btn_next}</button>
    </div>
</form>
<script type="text/javascript">
    $(function(){
        $("#install_form").validate({
            rules: {
                hostname: 'required',
                username: 'required',
                database: 'required'
            }
        });
    })

</script>