<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Info extends \Ciext\Controller\AbstractAdminController
{
    public function phpinfo()
    {
        phpinfo();
        exit;
    }
}