<?php 

$lang['title'] = 'Установка/Удаление модулей';

$lang['module_installed'] = 'Модуль установлен';
$lang['module_removed'] = 'Модуль удален';

$lang['ln_install'] = 'Установить';
$lang['ln_remove'] = 'Удалить';

$lang['res_name'] = 'Модуль';
$lang['res_alias'] = 'Псевдоним';

$lang['msg_install'] = 'Установить модуль ';
$lang['msg_uninstall'] = 'Удалить модуль ';

$lang['Return to list'] = '< Вернутся к списку';

$lang['Remove module from ACL'] = 'Удалить модуль с ACL';
$lang['Drop module tables'] = 'Удалить таблицы модуля';
$lang['Module was installed'] = 'Модуль установлен';
$lang['Module was removed'] = 'Модуль удален';